# AgentConnectorSystemInfo

System information for a connector instance. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**ConnectorStatsMetadata**](ConnectorStatsMetadata.md) |  | [optional] 
**os_info** | [**OSInfo**](OSInfo.md) |  | [optional] 
**kernel_info** | [**KernelInfo**](KernelInfo.md) |  | [optional] 
**cpu_info** | [**CpuInfo**](CpuInfo.md) |  | [optional] 
**memory_info** | [**MemoryInfo**](MemoryInfo.md) |  | [optional] 
**storage_info** | [**StorageInfo**](StorageInfo.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


